#
# spec file for package abi-dumper
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           abi-dumper
Version:        1.2
Release:        bp160.1.7
Summary:        Tool to dump ABI of an ELF object containing DWARF debug info
License:        LGPL-2.1-or-later
URL:            https://github.com/lvc/abi-dumper
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  help2man
Requires:       binutils
Requires:       elfutils
Requires:       gcc-c++
Requires:       vtable-dumper
Requires:       perl(Storable)
BuildArch:      noarch

%description
The tool is intended to be used with ABI Compliance Checker tool for tracking
ABI changes of a C/C++ library or kernel module.

%prep
%autosetup

%build
chmod 0755 %{name}.pl
ln -s %{name}.pl %{name}
help2man -N -o %{name}.1 ./%{name}

%install
mkdir -vp %{buildroot}%{_prefix}
env \
	"DESTDIR=%{buildroot}"  \
	perl Makefile.pl -install \
	--prefix=%{_prefix}
# Generate man page with help2man
mkdir -p %{buildroot}%{_mandir}/man1
install -m 0644 %{name}.1 %{buildroot}%{_mandir}/man1

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man*/*

%changelog
* Tue Jan  5 2021 Matthias Eliasson <elimat@opensuse.org>
- update to 1.2:
  * Support for Fedora 30
  * Misc fixes
- drop patches fixed in release:
  * 0001-Fixed-license-to-LGPL-2.1.patch
  * 0002-Fixed-license-file.patch
  * 0003-Support-for-new-elfutils-Fedora-30.patch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Jul  3 2019 Dan Čermák <dcermak@suse.com>
- Add 0001-Fixed-license-to-LGPL-2.1.patch
  Add 0002-Fixed-license-file.patch
  Add 0003-Support-for-new-elfutils-Fedora-30.patch
  fixes incorrect debuginfo extraction with new elfutils
* Sun Sep  3 2017 astieger@suse.com
- update to 1.1:
  * Support for compressing of ABI dumps before writing to drive
    from RAM
  * Fix analysis of inline functions (WARNING: old dumps should be
    regenerated before comparing by ABICC)
  * Deny analysis of static libraries
  * Bumped ABI dump version
* Wed Jul  5 2017 astieger@suse.com
- update to 1.0:
  * Up to 4 times less RAM usage
  * Reduce RAM usage on large compressed debug info
  * Minimal support for lambda expressions
  * Improve search for header files
  * Carefully handle lexical blocks
  * Detection of symbols in header files missed by Ctags
  * Detection of public typedefs
  * Support for unspecified_type
  * More debug messages
  * Print errors of the vtable-dumper
  * Add -ld-library-path option to specify paths to add to
    LD_LIBRARY_PATH variable before executing vtable-dumper
  * Add -lambda option to enable support for lambda and checking of
    lexical blocks
  * Add -ctags-def option to add '-D DEF' option to the ctags call
  * Add -all-units option to extract ABI info after reading of all
    compilation units
  * Add -include-defines option to add defines when creating TU
    dumps
  * Fix detection of a function header file
  * Fix analysis of inline functions
  * Fix analysis of template unions
  * Fix analysis of parameters
  * Fix analysis of typedefs
  * Fix analysis of zero-size structs
  * Fix -public-headers option
  * Fix analysis of global data
  * Fix analysis of templates
  * Fix analysis of anon data types
  * Fix analysis of symbol versions
  * Removed duplicates from ABI dump
  * Fix 'Copied' attribute of a class
  * Fix parameter offsets in the ABI dump
  * Fix analysis of standard C++ libraries
  * Fix analysis of MethodPtr types
* Thu May 11 2017 astieger@suse.com
- update to 0.99.19:
  * Improved support for incomplete debug-info
* Thu Oct  6 2016 davejplater@gmail.com
- Update to version 0.99.18
- Upstream changes since 0.99.17
  Improved support for incomplete debug-info.
- For previous version changes see:
  https://github.com/lvc/abi-dumper
* Mon May 11 2015 lnussel@suse.de
- new version 0.99.8.1
* Tue Mar 17 2015 lnussel@suse.de
- initial package version 0.99.8
